Detecting Viewer-Perceived Intended Vector Sketch Connectivity
==============================================================

<strong>Jerry Yin<sup>\*,1</sup>, Chenxi Liu<sup>\*,1</sup>, Rebecca Lin<sup>1</sup>, Nicholas Vining<sup>1,2</sup>, Helge Rhodin<sup>1</sup>, Alla Sheffer<sup>1</sup></strong>

<small><sup>\*</sup>joint first authors, <sup>1</sup>University of British Columbia, <sup>2</sup>NVIDIA</small>

This package contains data for the paper
[Detecting Viewer-Perceived Intended Vector Sketch Connectivity](https://www.cs.ubc.ca/labs/imager/tr/2022/SketchConnectivity/).

The corresponding code is in
[SketchConnectivity](https://github.com/squidrice21/SketchConnectivity).


Data
----

The `data` directory contains pre-processed inputs (line drawings) in the form of [VPaint][] VEC files, grouped based on their respective sources.
`data/human-annotations` contains junction annotations for drawings in the training set.

[VPaint]: https://www.vpaint.org/

Some of our VEC files were collected with time information.
We extend the format of typical strokes
```xml
<edge curve="xywdense(SAMPLING X0,Y0,WIDTH0 X1,Y1,WIDTH1 ..." />
```
to include time information as
```xml
<edge curve="xywtdense(SAMPLING X0,Y0,WIDTH0,TIME0 X1,Y1,WIDTH1,TIME1 ..." />
```
where `TIME` is a double-precision floating point value measuring the number of seconds since the Epoch when that sample was drawn.
Drawings without time information are ordinary VPaint files.


### Example of creating your own VEC file

```python
import _sketching as _s

drawing = _s.Drawing()

stroke = _s.Stroke(npoints=4, has_time=False)
stroke.x[:] = [1.0, 2.0, 3.0, 4.0]
stroke.y[:] = [5.0, 6.0, 7.0, 8.0]
stroke.width[:] = [0.5, 0.75, 1.0, 0.5]

drawing.add(stroke)

drawing.save('mydrawing.vec')
```


License
-------

The drawings are licensed under separate licenses.
Please refer to [`inputs_train+validate.yml`](data/inputs_train+validate.yml) for license information for each drawing.


BibTeX
------

```
@article{sketchconnectivity,
      title = {Detecting Viewer-Perceived Intended Vector Sketch Connectivity},
      author = {Yin, Jerry and Liu, Chenxi and Lin, Rebecca and Vining, Nicholas and Rhodin, Helge and Sheffer, Alla},
      year = 2022,
      journal = {ACM Transactions on Graphics},
      publisher = {ACM},
      address = {New York, NY, USA},
      volume = 41,
      number = 4,
      doi = {10.1145/3528223.3530097}
}
```
